@@ -148,6 +148,8 @@ PyAPI_FUNC(int) PyDelta_Check(struct _object *arg0);
 PyAPI_FUNC(int) PyDelta_CheckExact(struct _object *arg0);
 #define PyDescr_NewClassMethod PyPyDescr_NewClassMethod
 PyAPI_FUNC(PyObject *) PyDescr_NewClassMethod(PyTypeObject * arg0, PyMethodDef * arg1);
+#define PyDescr_NewGetSet PyPyDescr_NewGetSet
+PyAPI_FUNC(struct _object *) PyDescr_NewGetSet(struct _typeobject *arg0, struct PyGetSetDef *arg1);
 #define PyDictProxy_Check PyPyDictProxy_Check
 PyAPI_FUNC(int) PyDictProxy_Check(struct _object *arg0);
 #define PyDictProxy_CheckExact PyPyDictProxy_CheckExact
@@ -312,6 +314,8 @@ PyAPI_FUNC(int) PyFunction_Check(void * arg0);
 PyAPI_FUNC(int) PyFunction_CheckExact(void * arg0);
 #define PyFunction_GetCode PyPyFunction_GetCode
 PyAPI_FUNC(struct _object *) PyFunction_GetCode(struct _object *arg0);
+#define PyGILState_Check PyPyGILState_Check
+PyAPI_FUNC(int) PyGILState_Check(void);
 #define PyGILState_Ensure PyPyGILState_Ensure
 PyAPI_FUNC(int) PyGILState_Ensure(void);
 #define PyGILState_Release PyPyGILState_Release
@@ -796,6 +800,8 @@ PyAPI_FUNC(PyThreadState *) PyThreadState_Get(void);
 PyAPI_FUNC(struct _object *) PyThreadState_GetDict(void);
 #define PyThreadState_New PyPyThreadState_New
 PyAPI_FUNC(PyThreadState *) PyThreadState_New(PyInterpreterState *arg0);
+#define PyThreadState_SetAsyncExc PyPyThreadState_SetAsyncExc
+PyAPI_FUNC(int) PyThreadState_SetAsyncExc(Unsigned arg0, struct _object *arg1);
 #define PyThreadState_Swap PyPyThreadState_Swap
 PyAPI_FUNC(PyThreadState *) PyThreadState_Swap(PyThreadState *arg0);
 #define PyTime_Check PyPyTime_Check
